# Usage Example

from enstools.feature.pipeline import FeaturePipeline
from enstools.feature.identification.storm import StormIdentification
from enstools.feature.tracking.overlap_tracking import OverlapTracking
from enstools.feature.identification._proto_gen import storm_pb2
from os.path import expanduser
from enstools.feature.identification.storm.util import plot_timestep

# set the pb_reference to the compiled pb2.py file (see proto_gen directory)
pipeline = FeaturePipeline(storm_pb2, processing_mode='2d')

# change this to an identification strategy that actually does something: existing one or implement your own
i_strat = StormIdentification(some_parameter='foo') # set the Identification strategy
t_strat = OverlapTracking(field_name='storm_areas') # set the tracking strategy

pipeline.set_identification_strategy(i_strat)
pipeline.set_tracking_strategy(t_strat) # or None as argument if no tracking

path = expanduser("~") + '/phd/data/framework_example_ds/zeynep.nc'
pipeline.set_data_path(path)

# execute pipeline
pipeline.execute()

od = pipeline.get_object_desc()

reanalysis_set = od.sets[0]

# subset = get_subset_by_description(pipeline.get_data(), reanalysis_set, '2d')

for ts in reanalysis_set.timesteps:
    ds_t = pipeline.get_data().sel(time=ts.valid_time)

    plot_timestep(ds_t, str(ts.valid_time)[:13] + '.png')


out_json_path = path[:-3] + '_desc.json'
out_ds_path = path[:-3] + '_desc.nc'
out_graph_path = path[:-3] + '_graph.json'

pipeline.save_result(description_type='json', description_path=out_json_path, dataset_path=out_ds_path) # dataset_path=...


